@@ -331,16 +331,14 @@ module Kramdown
       end
 
       def convert_a(el, indent, opts)
-        do_obfuscation = el.attr['href'] =~ /^mailto:/
-        if do_obfuscation
-          el = el.deep_clone
-          href = obfuscate(el.attr['href'].sub(/^mailto:/, ''))
-          mailto = obfuscate('mailto')
-          el.attr['href'] = "#{mailto}:#{href}"
-        end
         res = inner(el, indent, opts)
-        res = obfuscate(res) if do_obfuscation
-        "<eref#{el_html_attributes(el)}>#{res}</eref>"
+        target = el.attr['target']
+        if target[0] == "#"     # handle [](#foo) as xref as in RFC 7328
+          el.attr['target'] = target[1..-1]
+          "<xref#{el_html_attributes(el)}>#{res}</xref>"
+        else
+          "<eref#{el_html_attributes(el)}>#{res}</eref>"
+        end
       end
 
       def convert_xref(el, indent, opts)
@@ -417,8 +415,14 @@ module Kramdown
         "<spanx#{attrstring}>#{escape_html(el.value)}</spanx>"
       end
 
-      def convert_footnote(el, indent, opts) # XXX: This is wrong.
-        "<xref target='#{escape_html(el.value)}'#{el_html_attributes(el)}/>"
+      def convert_footnote(el, indent, opts) # XXX: footnotes into crefs???
+        # this would be more like xml2rfc v3:
+        # "\n#{' '*indent}<cref>\n#{inner(el.value, indent, opts).rstrip}\n#{' '*indent}</cref>"
+        content = inner(el.value, indent, opts).strip
+        content = escape_html(content.sub(/\A<t>(.*)<\/t>\z/m) {$1}, :text) # text only...
+        name = el.options[:name].sub(/\A[0-9]/) {"_" << $&}
+        attrstring = el_html_attributes_with(el, {"anchor" => name})
+        "\n#{' '*indent}<cref#{attrstring}>#{content}</cref>"
       end
 
       def convert_raw(el, indent, opts)
